"""High-level API for accessing content."""

from .alts import (
    get_alts_to_id,
    get_id_to_alts,
    get_primary_curie,
    get_primary_identifier,
)
from .combine import get_literal_mappings_subset
from .edges import get_edges, get_edges_df, get_graph
from .hierarchy import (
    get_ancestors,
    get_children,
    get_descendants,
    get_hierarchy,
    get_subhierarchy,
    has_ancestor,
    is_descendent,
)
from .metadata import get_metadata
from .names import (
    get_definition,
    get_id_definition_mapping,
    get_id_name_mapping,
    get_id_synonyms_mapping,
    get_ids,
    get_literal_mappings,
    get_literal_mappings_df,
    get_name,
    get_name_by_curie,
    get_name_id_mapping,
    get_obsolete,
    get_obsolete_references,
    get_references,
    get_synonyms,
)
from .properties import (
    get_filtered_properties_df,
    get_filtered_properties_mapping,
    get_filtered_properties_multimapping,
    get_literal_properties,
    get_literal_properties_df,
    get_object_properties,
    get_object_properties_df,
    get_properties,
    get_properties_df,
    get_property,
)
from .relations import (
    get_filtered_relations_df,
    get_id_multirelations_mapping,
    get_relation,
    get_relation_mapping,
    get_relations_df,
)
from .species import get_id_species_mapping, get_species
from .typedefs import get_typedef_df
from .xrefs import (
    get_filtered_xrefs,
    get_mappings_df,
    get_sssom_df,
    get_xref,
    get_xrefs,
    get_xrefs_df,
)

__all__ = [
    "get_alts_to_id",
    "get_ancestors",
    "get_children",
    "get_definition",
    "get_descendants",
    "get_edges",
    "get_edges_df",
    "get_equivalent",
    "get_filtered_properties_df",
    "get_filtered_properties_mapping",
    "get_filtered_properties_multimapping",
    "get_filtered_relations_df",
    "get_filtered_xrefs",
    "get_graph",
    "get_hierarchy",
    "get_id_definition_mapping",
    "get_id_multirelations_mapping",
    "get_id_name_mapping",
    "get_id_species_mapping",
    "get_id_synonyms_mapping",
    "get_id_to_alts",
    "get_ids",
    "get_literal_mappings",
    "get_literal_mappings_df",
    "get_literal_mappings_subset",
    "get_literal_properties",
    "get_literal_properties_df",
    "get_mappings_df",
    "get_metadata",
    "get_name",
    "get_name_by_curie",
    "get_name_id_mapping",
    "get_object_properties",
    "get_object_properties_df",
    "get_obsolete",
    "get_obsolete_references",
    "get_ontology",
    "get_primary_curie",
    "get_primary_identifier",
    "get_priority_curie",
    "get_properties",
    "get_properties_df",
    "get_property",
    "get_references",
    "get_relation",
    "get_relation_mapping",
    "get_relations_df",
    "get_species",
    "get_sssom_df",
    "get_subhierarchy",
    "get_synonyms",
    "get_typedef_df",
    "get_version",
    "get_xref",
    "get_xrefs",
    "get_xrefs_df",
    "has_ancestor",
    "is_descendent",
]
